@@ -27,17 +27,19 @@
 #include "config.h"
 
 /* SYTEM (UNIX) includes */
-#include <stdio.h>
 #include <string.h>
 #include <time.h>
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 
+#include <glib/gstdio.h>
+
 /* GIMP includes */
 #include "libgimp/gimp.h"
 
 /* GAP includes */
+#include "gap_filter.h"
 
 /* int gap_debug = 1; */    /* print debug infos */
 /* int gap_debug = 0; */    /* 0: dont print debug infos */
@@ -50,8 +52,8 @@ gint gap_codegen_gen_code_iterator(char  *proc_name);
 
 void gap_codegen_remove_codegen_files()
 {
-   remove(GEN_FORWARDFILE_NAME);
-   remove(GEN_TABFILE_NAME);
+   g_remove(GEN_FORWARDFILE_NAME);
+   g_remove(GEN_TABFILE_NAME);
 
    printf("overwrite  file: %s\n", GEN_FORWARDFILE_NAME);
    printf("overwrite  file: %s\n", GEN_TABFILE_NAME);
@@ -205,7 +207,7 @@ gint gap_codegen_gen_code_iter_ALT(char  *proc_name)
      if (l_params[2].type !=  GIMP_PDB_DRAWABLE) { l_rc = -1;  }
 
      g_snprintf(l_filename, sizeof(l_filename), "%s_iter_ALT.inc", l_clean_proc_name);
-     l_fp = fopen(l_filename, "w");
+     l_fp = g_fopen(l_filename, "w");
      if(l_fp != NULL)
      {
        fprintf(l_fp, "/* ----------------------------------------------------------------------\n");
@@ -230,13 +232,13 @@ gint gap_codegen_gen_code_iter_ALT(char  *proc_name)
        fprintf(l_fp, "\n");
        fprintf(l_fp, "    if(len_struct != sizeof(t_%s_Vals)) \n", l_clean_proc_name);
        fprintf(l_fp, "    {\n");
-       fprintf(l_fp, "      fprintf(stderr, \"ERROR: p_\%s_iter_ALT  stored Data missmatch in size %%d != %%d\\n\",   \n", l_clean_proc_name);
+       fprintf(l_fp, "      printf(\"ERROR: p_\%s_iter_ALT  stored Data missmatch in size %%d != %%d\\n\",   \n", l_clean_proc_name);
        fprintf(l_fp, "                       (int)len_struct, sizeof(t_%s_Vals) ); \n", l_clean_proc_name);
        fprintf(l_fp, "      return -1;  /* ERROR */ \n");
        fprintf(l_fp, "    }\n");
        fprintf(l_fp, "\n");
-       fprintf(l_fp, "    gimp_get_data(\"%s_ITER_FROM\", g_plugin_data_from); \n", l_clean_proc_name);
-       fprintf(l_fp, "    gimp_get_data(\"%s_ITER_TO\",   g_plugin_data_to); \n", l_clean_proc_name);
+       fprintf(l_fp, "    gimp_get_data(\"%s%s\", g_plugin_data_from); \n", l_clean_proc_name, GAP_ITER_FROM_SUFFIX);
+       fprintf(l_fp, "    gimp_get_data(\"%s%s\",   g_plugin_data_to); \n", l_clean_proc_name, GAP_ITER_TO_SUFFIX);
        fprintf(l_fp, "\n");
        fprintf(l_fp, "    buf_from = (t_%s_Vals *)&g_plugin_data_from[0]; \n", l_clean_proc_name);
        fprintf(l_fp, "    buf_to   = (t_%s_Vals *)&g_plugin_data_to[0]; \n", l_clean_proc_name);
@@ -313,7 +315,7 @@ gint gap_codegen_gen_forward_iter_ALT(char  *proc_name)
   char             l_clean_proc_name[256];
 
   p_clean_name(proc_name, &l_clean_proc_name[0]);
-  l_fp = fopen(GEN_FORWARDFILE_NAME, "a");
+  l_fp = g_fopen(GEN_FORWARDFILE_NAME, "a");
   if(l_fp != NULL)
   {
     fprintf(l_fp, "static gint p_%s_iter_ALT (GimpRunMode run_mode, gint32 total_steps, gdouble current_step, gint32 len_struct);\n",
@@ -329,7 +331,7 @@ gint gap_codegen_gen_tab_iter_ALT(char  *proc_name)
   char             l_clean_proc_name[256];
 
   p_clean_name(proc_name, &l_clean_proc_name[0]);
-  l_fp = fopen(GEN_TABFILE_NAME, "a");
+  l_fp = g_fopen(GEN_TABFILE_NAME, "a");
   if(l_fp != NULL)
   {
     fprintf(l_fp, "   , { \"%s\",  p_%s_iter_ALT }\n",
@@ -398,7 +400,7 @@ gint gap_codegen_gen_code_iterator(char  *proc_name)
 
      g_snprintf(l_filename, sizeof(l_filename), "%s_iter.c", l_clean_proc_name);
 
-     l_fp = fopen(l_filename, "w");
+     l_fp = g_fopen(l_filename, "w");
      if(l_fp != NULL)
      {
 
@@ -596,8 +598,8 @@ gint gap_codegen_gen_code_iterator(char  *proc_name)
        fprintf(l_fp, "      return -1;  /* ERROR */ \n");
        fprintf(l_fp, "    }\n");
        fprintf(l_fp, "\n");
-       fprintf(l_fp, "    gimp_get_data(\"%s_ITER_FROM\", &buf_from); \n", l_clean_proc_name);
-       fprintf(l_fp, "    gimp_get_data(\"%s_ITER_TO\",   &buf_to); \n", l_clean_proc_name);
+       fprintf(l_fp, "    gimp_get_data(\"%s%s\", &buf_from); \n", l_clean_proc_name, GAP_ITER_FROM_SUFFIX);
+       fprintf(l_fp, "    gimp_get_data(\"%s%s\",   &buf_to); \n", l_clean_proc_name, GAP_ITER_TO_SUFFIX);
        fprintf(l_fp, "    memcpy(&buf, &buf_from, sizeof(buf));\n");
        fprintf(l_fp, "\n");
 
@@ -644,7 +646,7 @@ gint gap_codegen_gen_code_iterator(char  *proc_name)
        fprintf(l_fp, "MAIN ()\n");
        fprintf(l_fp, "\n");
        fprintf(l_fp, "/* ----------------------------------------------------------------------\n");
-       fprintf(l_fp, " * install (query) _Iterator\n");
+       fprintf(l_fp, " * install (query) %s\n", GAP_ITERATOR_SUFFIX);
        fprintf(l_fp, " * ----------------------------------------------------------------------\n");
        fprintf(l_fp, " */\n");
        fprintf(l_fp, "\n");
@@ -666,7 +668,7 @@ gint gap_codegen_gen_code_iterator(char  *proc_name)
        fprintf(l_fp, "\n");
        fprintf(l_fp, "  g_snprintf(l_blurb_text, sizeof(l_blurb_text), \"This procedure calculates the modified values for one iterationstep for the call of %s\");\n", l_clean_proc_name);
        fprintf(l_fp, "\n");
-       fprintf(l_fp, "  gimp_install_procedure(\"%s_Iterator\",\n", l_clean_proc_name);
+       fprintf(l_fp, "  gimp_install_procedure(\"%s%s\",\n", l_clean_proc_name, GAP_ITERATOR_SUFFIX);
        fprintf(l_fp, "                         l_blurb_text,\n");
        fprintf(l_fp, "                         \"\",\n");
        fprintf(l_fp, "                         \"Wolfgang Hofer\",\n");
