@@ -1970,6 +1970,8 @@ p_layer_warp_move (GapMorphWorkPoint     *wp_list_1
                       );
   gimp_pixel_fetcher_destroy (src_pixfet);
 
+  gimp_drawable_detach(src_drawable);
+  gimp_drawable_detach(dst_drawable);
 }   /* end p_layer_warp_move */
 
 /* ---------------------------------
@@ -2105,6 +2107,9 @@ p_mix_layers (gint32  curr_image_id
                       , dst_drawable->height
                       );
 
+  gimp_drawable_detach(bg_drawable);
+  gimp_drawable_detach(top_drawable);
+  gimp_drawable_detach(dst_drawable);
 
   return(dst_layer_id);
 
@@ -2380,6 +2385,7 @@ p_create_morph_tween_frame(gint32 total_steps
      gap_morph_exec_free_workpoint_list(&curr_wp_list_1);
    }
 
+   gimp_drawable_detach(dst_drawable);
 
    if(mgpp->render_mode == GAP_MORPH_RENDER_MODE_WARP)
    {
