@@ -69,8 +69,6 @@ gchar* p_build_format_from_framename(gchar *framename);
 /* Includes for extra LIBS */
 
 
-static char *gap_enc_single_version = "1.2.2b; 2002/11/24";
-
 #define GAP_PLUGIN_NAME_SINGLEFRAMES_ENCODE     "plug_in_gap_enc_singleframes"
 
 /* ------------------------
@@ -188,11 +186,11 @@ query ()
                          " audiodata is ignored."
                          " A  call of"
                          "\"" GAP_PLUGIN_NAME_SINGLEFRAMES_PARAMS  "\""
-                         " to set encoder specific paramters, is not required because"
-                         " this release of the singleframe encoder has NO encoder specific paramters"),
+                         " to set encoder specific parameters, is not required because"
+                         " this release of the singleframe encoder has NO encoder specific parameters"),
                          "Wolfgang Hofer (hof@gimp.org)",
                          "Wolfgang Hofer",
-                         gap_enc_single_version,
+                         GAP_VERSION_WITH_DATE,
                          NULL,                      /* has no Menu entry, just a PDB interface */
                          "RGB*, INDEXED*, GRAY*",
                          GIMP_PLUGIN,
@@ -206,7 +204,7 @@ query ()
                          _("This plugin sets singleframes specific video encoding parameters."),
                          "Wolfgang Hofer (hof@gimp.org)",
                          "Wolfgang Hofer",
-                         gap_enc_single_version,
+                         GAP_VERSION_WITH_DATE,
                          NULL,                      /* has no Menu entry, just a PDB interface */
                          NULL,
                          GIMP_PLUGIN,
@@ -220,7 +218,7 @@ query ()
                          _("This plugin returns singleframes encoder specific parameters."),
                          "Wolfgang Hofer (hof@gimp.org)",
                          "Wolfgang Hofer",
-                         gap_enc_single_version,
+                         GAP_VERSION_WITH_DATE,
                          NULL,                      /* has no Menu entry, just a PDB interface */
                          NULL,
                          GIMP_PLUGIN,
@@ -238,7 +236,7 @@ query ()
  */
 static void
 run (const gchar *name,          /* name of plugin */
-     gint n_params,               /* number of in-paramters */
+     gint n_params,              /* number of in-parameters */
      const GimpParam * param,    /* in-parameters */
      gint *nreturn_vals,         /* number of out-parameters */
      GimpParam ** return_vals)   /* out-parameters */
@@ -721,7 +719,7 @@ p_singleframe_encode(GapGveSingleGlobalParams *gpp)
        if(gpp->val.run_mode == GIMP_RUN_INTERACTIVE)
        {
          char *l_msg;
-	 
+
 	 l_msg = g_strdup_printf(_("SAVING: %s\n"), l_sav_name);
          gimp_progress_init(l_msg);
          g_free(l_msg);
